==> tinyvisor-1.4.tar.gz: tinyvisor/vmm/drivers/dmar.h <==
/*
 * From BitVisor 1.0.1 include/passthrough/dmar.h
 */
/*
 * Copyright (c) 2007, 2008 University of Tsukuba
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. Neither the name of the University of Tsukuba nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
/*
 * Copyright (c) 2010-2012 Yuichi Watanabe
 */

#ifndef _ACPI_DMAR_H_
#define _ACPI_DMAR_H_

#include <common/list.h>
#include <core/spinlock.h>

struct iommu;

struct pci_dev {
        u8 bus;
        union {
                u8 devfn ;
                struct {
                        unsigned int func_no: 3 ;
                        unsigned int dev_no: 5 ;
                } df ;
        } ;
};

struct dmar_drhd_u {
	LIST_DEFINE(drhd_list) ;
	u64    address; /* register base address of the unit */
	struct    pci_dev *devices; /* target devices */
	int    devices_cnt;
	u8    include_pci_all;
	struct iommu *iommu;
};

int dmar_drhd_exists();
struct dmar_drhd_u* dmar_get_next_drhd(struct dmar_drhd_u* cur);
struct iommu *dmar_matched_iommu(u8 bus, u8 devfn);

#endif /* _ACPI_DMAR_H_ */

==> tinyvisor-1.7.tar.gz: tinyvisor/vmm/drivers/dmar.h <==
/*
 * From BitVisor 1.0.1 include/passthrough/dmar.h
 */
/*
 * Copyright (c) 2007, 2008 University of Tsukuba
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. Neither the name of the University of Tsukuba nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
/*
 * Copyright (c) 2010-2012 Yuichi Watanabe
 */

#ifndef _ACPI_DMAR_H_
#define _ACPI_DMAR_H_

#include <common/list.h>
#include <core/spinlock.h>

struct iommu;

struct pci_dev {
        u8 bus;
        union {
                u8 devfn ;
                struct {
                        unsigned int func_no: 3 ;
                        unsigned int dev_no: 5 ;
                } df ;
        } ;
};

struct dmar_drhd_u {
	LIST_DEFINE(drhd_list) ;
	u64    address; /* register base address of the unit */
	struct    pci_dev *devices; /* target devices */
	int    devices_cnt;
	u8    include_pci_all;
	struct iommu *iommu;
};

void dmar_init(void);
int dmar_drhd_exists(void);
struct dmar_drhd_u* dmar_get_next_drhd(struct dmar_drhd_u* cur);
struct iommu *dmar_matched_iommu(u8 bus, u8 devfn);

#endif /* _ACPI_DMAR_H_ */
